@@ -41,7 +41,9 @@ var corefileTemplate = template.Must(template.New("Corefile").Parse(`{{range .Se
     forward . /etc/resolv.conf {
         policy sequential
     }
-    cache 30
+    cache 900 {
+        denial 9984 30
+    }
     reload
 }
 `))
